summaryrefslogtreecommitdiff
path: root/interface/PluginInterface_SessionLoader.h
diff options
context:
space:
mode:
authorThomas Preud'homme <robotux@celest.fr>2017-11-24 23:24:09 +0000
committerThomas Preud'homme <robotux@celest.fr>2017-11-24 23:24:09 +0000
commitb3c8bdcc0d1e4b2ab298847a7902b6d60410a5bc (patch)
tree8fce8a51adfb245db8ab2a76831661780c0c713e /interface/PluginInterface_SessionLoader.h
parente297dbd8052ef4e66f069e2dd1865ae7fa8af28e (diff)
New upstream version 1.2.3.6
Diffstat (limited to 'interface/PluginInterface_SessionLoader.h')
-rw-r--r--interface/PluginInterface_SessionLoader.h33
1 files changed, 18 insertions, 15 deletions
diff --git a/interface/PluginInterface_SessionLoader.h b/interface/PluginInterface_SessionLoader.h
index e73c9e3..85b9b22 100644
--- a/interface/PluginInterface_SessionLoader.h
+++ b/interface/PluginInterface_SessionLoader.h
@@ -1,8 +1,7 @@
/** \file PluginInterface_SessionLoader.h
\brief Define the interface of the plugin of type: session loader
\author alpha_one_x86
-\version 0.3
-\date 2010 */
+\licence GPL3, see the file COPYING */
#ifndef PLUGININTERFACE_SESSIONLOADER_H
#define PLUGININTERFACE_SESSIONLOADER_H
@@ -17,20 +16,24 @@
* */
class PluginInterface_SessionLoader : public QObject
{
- public:
- /// \brief set enabled/disabled
- virtual void setEnabled(bool) = 0;
- /// \brief get if is enabled
- virtual bool getEnabled() = 0;
- /// \brief set the resources
- virtual void setResources(OptionInterface * options,QString writePath,QString pluginPath,bool portableVersion) = 0;
- /// \brief to get the options widget, NULL if not have
- virtual QWidget * options() = 0;
- public slots:
- /// \brief to reload the translation, because the new language have been loaded
- virtual void newLanguageLoaded() = 0;
+ Q_OBJECT
+ public:
+ /// \brief set enabled/disabled
+ virtual void setEnabled(const bool &enabled) = 0;
+ /// \brief get if is enabled
+ virtual bool getEnabled() const = 0;
+ /// \brief set the resources
+ virtual void setResources(OptionInterface * options,const QString &writePath,const QString &pluginPath,const bool &portableVersion) = 0;
+ /// \brief to get the options widget, NULL if not have
+ virtual QWidget * options() = 0;
+ public slots:
+ /// \brief to reload the translation, because the new language have been loaded
+ virtual void newLanguageLoaded() = 0;
+ signals:
+ /// \brief To debug source
+ void debugInformation(const Ultracopier::DebugLevel &level,const QString &fonction,const QString &text,const QString &file,const int &ligne) const;
};
-Q_DECLARE_INTERFACE(PluginInterface_SessionLoader,"first-world.info.ultracopier.PluginInterface.SessionLoader/0.3.0.8");
+Q_DECLARE_INTERFACE(PluginInterface_SessionLoader,"first-world.info.ultracopier.PluginInterface.SessionLoader/1.0.0.0");
#endif // PLUGININTERFACE_SESSIONLOADER_H